==> worker_2.10.2.orig.tar.gz: worker-2.10.2/src/textstoragefile.cc <==
/* textstoragefile.cc
 * This file belongs to Worker, a filemanager for UNIX/X11.
 * Copyright (C) 2005 Ralf Hoffmann.
 * You can contact me at: ralf@boomerangsworld.de
 *   or http://www.boomerangsworld.de/worker
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/* $Id: textstoragefile.cc,v 1.3 2005/06/09 04:32:54 ralf Exp $ */

#include "textstoragefile.h"
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <unistd.h>
#include "worker_locale.h"

TextStorageFile::TextStorageFile( std::string filename ) : tss( "" )
{
  int fd;
  int read_bytes;
  char buffer[ 64 * 1024 ];

  fd = worker_open( filename.c_str(), O_RDONLY, 0 );
  if ( fd >= 0 ) {
    read_bytes = worker_read( fd, buffer, sizeof( buffer ) );
    if ( read_bytes >= 0 ) {

      // tab replacing
      int pos = 0;
      std::string notab_buffer;
      
      for ( int i = 0; i < read_bytes; i++ ) {
	if ( buffer[i] != '\t' ) {
	  notab_buffer += buffer[i];
	  if ( buffer[i] == '\n' ) pos = 0;
	  else pos++;
	} else {
	  notab_buffer.append( 8 - ( pos % 8 ), ' ' );
	  pos += 8 - ( pos % 8 );
	}
      }

      //      tss = TextStorageString( buffer, read_bytes );
      tss = TextStorageString( notab_buffer );
    } else {
      char *tstr = (char*)_allocsafe( strlen( catalog.getLocale( 281 ) ) +
				      strlen( filename.c_str() ) + 1 );
      sprintf( tstr, catalog.getLocale( 281 ), filename.c_str() );
      tss = TextStorageString( tstr );
      _freesafe( tstr );
    }
    worker_close( fd );
  }
}

int TextStorageFile::getNrOfLines() const
{
  return tss.getNrOfLines();
}

int TextStorageFile::getLine( int line_nr, unsigned int offset, int len, std::string &return_line ) const
{
  return tss.getLine( line_nr, offset, len, return_line );
}

int TextStorageFile::getLine( int line_nr, unsigned int offset, std::string &return_line ) const
{
  return getLine( line_nr, offset, -1, return_line );
}

int TextStorageFile::getMaxLineLen() const
{
  return tss.getMaxLineLen();
}

int TextStorageFile::getLineLen( int line_nr ) const
{
  return tss.getLineLen( line_nr );
}

void TextStorageFile::setLineLimit( int new_limit )
{
  tss.setLineLimit( new_limit );
}

==> worker_2.11.1.orig.tar.gz: worker-2.11.1/src/textstoragefile.cc <==
/* textstoragefile.cc
 * This file belongs to Worker, a filemanager for UNIX/X11.
 * Copyright (C) 2005 Ralf Hoffmann.
 * You can contact me at: ralf@boomerangsworld.de
 *   or http://www.boomerangsworld.de/worker
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/* $Id: textstoragefile.cc,v 1.4 2005/08/17 06:33:06 ralf Exp $ */

#include "textstoragefile.h"
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <unistd.h>
#include "worker_locale.h"

TextStorageFile::TextStorageFile( std::string filename, AWidth &lencalc ) : tss( "", lencalc )
{
  int fd;
  int read_bytes;
  char buffer[ 64 * 1024 ];

  fd = worker_open( filename.c_str(), O_RDONLY, 0 );
  if ( fd >= 0 ) {
    read_bytes = worker_read( fd, buffer, sizeof( buffer ) );
    if ( read_bytes >= 0 ) {

      // tab replacing
      int pos = 0;
      std::string notab_buffer;
      
      for ( int i = 0; i < read_bytes; i++ ) {
	if ( buffer[i] != '\t' ) {
	  notab_buffer += buffer[i];
	  if ( buffer[i] == '\n' ) pos = 0;
	  else pos++;
	} else {
	  notab_buffer.append( 8 - ( pos % 8 ), ' ' );
	  pos += 8 - ( pos % 8 );
	}
      }

      //      tss = TextStorageString( buffer, read_bytes );
      tss = TextStorageString( notab_buffer, lencalc );
    } else {
      char *tstr = (char*)_allocsafe( strlen( catalog.getLocale( 281 ) ) +
				      strlen( filename.c_str() ) + 1 );
      sprintf( tstr, catalog.getLocale( 281 ), filename.c_str() );
      tss = TextStorageString( tstr, lencalc );
      _freesafe( tstr );
    }
    worker_close( fd );
  }
}

int TextStorageFile::getNrOfLines() const
{
  return tss.getNrOfLines();
}

int TextStorageFile::getLine( int line_nr, unsigned int offset, int len, std::string &return_line ) const
{
  return tss.getLine( line_nr, offset, len, return_line );
}

int TextStorageFile::getLine( int line_nr, unsigned int offset, std::string &return_line ) const
{
  return getLine( line_nr, offset, -1, return_line );
}

int TextStorageFile::getMaxLineWidth() const
{
  return tss.getMaxLineWidth();
}

int TextStorageFile::getLineWidth( int line_nr ) const
{
  return tss.getLineWidth( line_nr );
}

void TextStorageFile::setLineLimit( int new_limit )
{
  tss.setLineLimit( new_limit );
}
